/*
 * TIDA-01162
 *
 * Integrated vs Discrete Low Voltage Motor Drive Comparison
 *
 * Copyright (C) 2016 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

// Unidirectional motor driver DRV8850
#include "msp430g2553.h"

// GPIO Port 1 Definitions
#define nSLEEP      BIT0    // P1.0 Note: For discrete part change nSLEEP for FAULT_MSP
#define POT2      	BIT1    // P1.1
#define LED2      	BIT2    // P1.2
#define VPROPI		BIT3    // P1.3
#define NC2         BIT4    // P1.4
#define NC3        	BIT5    // P1.5
#define NC4         BIT6    // P1.6
#define NC5         BIT7    // P1.7

// GPIO Port 2 Definitions
#define NC6         BIT0    // P2.0
#define PWM_3       BIT1    // P2.1
#define NC7      	BIT2    // P2.2
#define NC8	      	BIT3    // P2.3
#define PWM_4       BIT4    // P2.4
#define NC9      	BIT5    // P2.5
#define NC10        BIT6    // P2.6
#define NC11    	BIT7    // P2.7

unsigned int DutyCycle1;                // PWM duty cycle
unsigned int DutyCycle2;

// Function prototypes
void Init_Sys(void);                    // Initalize System and Module
void DoPOTI(void);                      // Get POTI Input

void main(void)
{
	Init_Sys();                         // Initialize  system
  while (1){
    _BIS_SR(LPM0_bits + GIE);           // Enter LPM0 with interrupts
    DoPOTI();                           // Get POTI value with ADC10
    TA1CCR1 = DutyCycle1;               // PWM duty cycle to DRV

    	P2OUT |= PWM_3;                 // IN_2 set
    	P2SEL |= PWM_3;                 // Enable IN_1 PWM

    TA1CCR2 = DutyCycle2;

    	P2OUT |= PWM_4;
    	P2SEL |= PWM_4;

    P1OUT ^= LED2;                      // Toggle LED
  }
}

/*------------------------------------------------------------------------------
   Input: A0 Analog Input
  Output: DutyCycle
------------------------------------------------------------------------------*/
  void DoPOTI (void) {
  ADC10CTL0 &= ~ENC;                  	// Configure ADC enabled
  ADC10CTL1 = INCH_1;                 	// ADC10MEM = A1
  ADC10CTL0 = ADC10SHT_2 + ADC10ON;
  ADC10CTL0 |= ENC + ADC10SC;         	// Sampling and conversion start
  while (ADC10IFG & ADC10CTL0);       	// Wait for conversion complete
  ADC10CTL0 &= ~ADC10IFG;             	// Clear converstion flag
  DutyCycle1 = ADC10MEM>>4;            	// Mask upper 4-bits
  DutyCycle2 = ADC10MEM>>4;
}

/*-----------------------------------------------------------------------------
  Initalize System and Module
------------------------------------------------------------------------------*/
void Init_Sys(void){
  WDTCTL = WDT_MDLY_32;                 // Set Watchdog Timer interval to ~30ms
  IE1 |= WDTIE;                         // Enable WDT interrupt
  BCSCTL1 = CALBC1_1MHZ;                // Set DCO to 1MHz
  DCOCTL = CALDCO_1MHZ;

/*----------------------------------------------------------------------------------
 *  To drive the discrete part of the board. the same code can be used but nSLEEP
 * needs to be changed from a high to low output
---------------------------------------------------------------------------------- */
  P1DIR = nSLEEP + LED2;

  //Configure GPIO
  P2OUT = 0x00;
  P2SEL = 0x00;
  P2DIR = PWM_3 + PWM_4;

  // Setup Timer A1
  TA1CCTL1 = OUTMOD_3;					// TA1.1 set/reset mode
  TA1CCTL2 = OUTMOD_3;                  // TA1.2 set/reset mode
  TA1CCR1 = 0;							// TA1CCR1 Duty cycle to 0%
  TA1CCR0 = 64 - 1;                     // 6-bit PWM period
  TA1CTL = TASSEL_2 + MC_1;             // SCLK source, up mode

  // Configure ADC
  ADC10AE0 |= INCH_1;                   // P1.1 ADC option select
}

// Watchdog Timer interrupt service routine
#pragma vector=WDT_VECTOR
__interrupt void watchdog_timer(void)
{
  _BIC_SR_IRQ(LPM0_bits);                 // Clear LPM0 bits from 0(SR)
}
